#

    	voting
    		# voting
    		# picking
    		# choosing
    		# share

    		# consensus
    			# course
    			# governance
    			# forward
    			# management
    			# directions
    			# strategy
    			# procedures

    		# laws, rules, physics

    		# citizens,
    			# councilor,
    			# accountants,

    			# choosers,
    			# authors,

    			# voters,
    			# governments,
    			# politicians,
    			# rulers,
    			# writers,
    			# producers,
    			# board,
    			# family